==> li-pagador-paypal-1.0.3.tar.gz: li-pagador-paypal-1.0.3/src/pagador_paypal/extensao/configuracao.py <==
# -*- coding: utf-8 -*-
import os

from pagador.configuracao.cadastro import CampoFormulario, FormularioBase, TipoDeCampo, CadastroBase, SelecaoBase, caminho_para_template
from pagador.configuracao.cliente import Script, TipoScript
from pagador_koin import settings


def caminho_do_arquivo_de_template(arquivo):
    return caminho_para_template(arquivo, meio_pagamento='paypal')


class MeioPagamentoCadastro(CadastroBase):
    logo = Script(tipo=TipoScript.html, nome="logo", conteudo=u'<img src="https://www.paypalobjects.com/webstatic/i/logo/rebrand/ppcom.png" border="0" alt="PayPal" />')

    @property
    def descricao_para_lojista(self):
        script = Script(tipo=TipoScript.html, nome="descricao")
        script.adiciona_linha('<h3>É seguro. É fácil. É PayPal</h3>')
        script.adiciona_linha('<p>São mais de 140 milhões de clientes no mundo todo comprando com segurança e facilidade.</p>')
        script.adiciona_linha('<p>Saiba mais <a href="https://www.paypal.com/br/webapps/mpp/accept-payments-online" target="_blank">aqui</a></p>')
        return script

    @property
    def registro(self):
        script = Script(tipo=TipoScript.html, nome="registro")
        script.adiciona_linha(u'Ainda não tem conta no PayPal?')
        script.adiciona_linha('<a href="https://www.paypal.com/br/cgi-bin/webscr?cmd=_registration-run-validated&country=BR&cid=MCSG5F2W3J6G6LVW" title="Criar conta no PayPal" class="btn btn-info btn-xs" target="_blank">cadastre-se</a>')
        return script

    def to_dict(self):
        return {
            "html": [
                self.descricao_para_lojista.to_dict(),
                self.registro.to_dict()
            ]
        }


PARCELAS = [(x, x) for x in range(1, 13)]
PARCELAS.insert(0, (12, "Todas"))


class Formulario(FormularioBase):
    usuario = CampoFormulario("usuario", u"Seu usuário PayPal", requerido=True, tamanho_max=128, ordem=1)
    mostrar_parcelamento = CampoFormulario("mostrar_parcelamento", "Marque para mostrar o parcelamento na listagem e na página do produto.", tipo=TipoDeCampo.boleano, requerido=False, ordem=2)
    parcelas_sem_juros = CampoFormulario("parcelas_sem_juros", "Parcelas sem juros", tipo=TipoDeCampo.escolha, requerido=False, ordem=4, texto_ajuda=u"Número de parcelas sem juros para esta forma de pagamento.", opcoes=PARCELAS)


class MeioPagamentoEnvio(object):
    @property
    def css(self):
        return Script(tipo=TipoScript.css, caminho_arquivo=caminho_do_arquivo_de_template("style.css"))

    @property
    def function_enviar(self):
        return Script(tipo=TipoScript.javascript, eh_template=True, caminho_arquivo=caminho_do_arquivo_de_template("javascript.js"))

    @property
    def mensagens(self):
        return Script(tipo=TipoScript.html, caminho_arquivo=caminho_do_arquivo_de_template("mensagens.html"))

    def to_dict(self):
        return [
            self.css.to_dict(),
            self.function_enviar.to_dict(),
            self.mensagens.to_dict()
        ]


class MeioPagamentoSelecao(SelecaoBase):
    selecao = Script(tipo=TipoScript.html, nome="selecao", caminho_arquivo=caminho_do_arquivo_de_template("selecao.html"), eh_template=True)

    def to_dict(self):
        return [
            self.selecao.to_dict()
        ]

==> li-pagador-paypal-1.0.6.tar.gz: li-pagador-paypal-1.0.6/src/pagador_paypal/extensao/configuracao.py <==
# -*- coding: utf-8 -*-
import os

from pagador.configuracao.cadastro import CampoFormulario, FormularioBase, TipoDeCampo, CadastroBase, SelecaoBase, caminho_para_template
from pagador.configuracao.cliente import Script, TipoScript
from pagador_koin import settings


def caminho_do_arquivo_de_template(arquivo):
    return caminho_para_template(arquivo, meio_pagamento='paypal')


class MeioPagamentoCadastro(CadastroBase):
    logo = Script(tipo=TipoScript.html, nome="logo", conteudo=u'<img src="https://www.paypalobjects.com/webstatic/i/logo/rebrand/ppcom.png" border="0" alt="PayPal" />')

    @property
    def descricao_para_lojista(self):
        script = Script(tipo=TipoScript.html, nome="descricao")
        script.adiciona_linha('<h3>É seguro. É fácil. É PayPal</h3>')
        script.adiciona_linha('<p>São mais de 140 milhões de clientes no mundo todo comprando com segurança e facilidade.</p>')
        script.adiciona_linha('<p>Saiba mais <a href="https://www.paypal.com/br/webapps/mpp/accept-payments-online" target="_blank">aqui</a></p>')
        return script

    @property
    def registro(self):
        script = Script(tipo=TipoScript.html, nome="registro")
        script.adiciona_linha(u'Ainda não tem conta no PayPal?')
        script.adiciona_linha('<a href="https://www.paypal.com/br/cgi-bin/webscr?cmd=_registration-run-validated&country=BR&cid=MCSG5F2W3J6G6LVW" title="Criar conta no PayPal" class="btn btn-info btn-xs" target="_blank">cadastre-se</a>')
        return script

    def to_dict(self):
        return {
            "html": [
                self.descricao_para_lojista.to_dict(),
                self.registro.to_dict()
            ]
        }


PARCELAS = [(x, x) for x in range(1, 13)]
PARCELAS.insert(0, (12, "Todas"))


class Formulario(FormularioBase):
    usuario = CampoFormulario("usuario", u"Seu usuário PayPal", requerido=True, tamanho_max=128, ordem=1)
    valor_minimo_aceitado = CampoFormulario("valor_minimo_aceitado", u"Valor mínimo", requerido=False, decimais=2, ordem=2, tipo=TipoDeCampo.decimal, texto_ajuda=u"Informe o valor mínimo para exibir esta forma de pagamento.")
    valor_minimo_parcela = CampoFormulario("valor_minimo_parcela", u"Valor mínimo da parcela", requerido=False, decimais=2, ordem=3, tipo=TipoDeCampo.decimal)
    mostrar_parcelamento = CampoFormulario("mostrar_parcelamento", "Marque para mostrar o parcelamento na listagem e na página do produto.", tipo=TipoDeCampo.boleano, requerido=False, ordem=4)
    parcelas_sem_juros = CampoFormulario("parcelas_sem_juros", "Parcelas sem juros", tipo=TipoDeCampo.escolha, requerido=False, ordem=5, texto_ajuda=u"Número de parcelas sem juros para esta forma de pagamento.", opcoes=PARCELAS)


class MeioPagamentoEnvio(object):
    @property
    def css(self):
        return Script(tipo=TipoScript.css, caminho_arquivo=caminho_do_arquivo_de_template("style.css"))

    @property
    def function_enviar(self):
        return Script(tipo=TipoScript.javascript, eh_template=True, caminho_arquivo=caminho_do_arquivo_de_template("javascript.js"))

    @property
    def mensagens(self):
        return Script(tipo=TipoScript.html, caminho_arquivo=caminho_do_arquivo_de_template("mensagens.html"))

    def to_dict(self):
        return [
            self.css.to_dict(),
            self.function_enviar.to_dict(),
            self.mensagens.to_dict()
        ]


class MeioPagamentoSelecao(SelecaoBase):
    selecao = Script(tipo=TipoScript.html, nome="selecao", caminho_arquivo=caminho_do_arquivo_de_template("selecao.html"), eh_template=True)

    def to_dict(self):
        if not self.aceita_pagamento_no_valor():
            return []
        return [
            self.selecao.to_dict()
        ]
